// ShowArgs.pp
// Written by Bill Stewart (bstewart@iname.com)
//
// This is a short program that outputs its entire command line. This is useful
// for troubleshooting command line parsing problems: You can substitute
// ShowArgs.exe (or ShowArgs-GUI.exe) for the program you're running. This
// program isn't really needed in shell scripts (batch files) because cmd.exe's
// 'echo' command already does this. However this program can be nearly
//  indespensible when troubleshooting PowerShell scripts that call command
// line programs because PowerShell lacks a cmd.exe-like 'echo' statement for
// outputting the command line instead of running it.

{$IFNDEF GUI}
{$APPTYPE CONSOLE}
{$R ShowArgs.res}
{$ELSE}
{$APPTYPE GUI}
{$R ShowArgs-GUI.res}
{$ENDIF}

Uses
  Windows;

Var
  pCommandTail: PChar;

Function GetCommandTail: PChar;
  Const
    WHITESPACE: Set Of Char = [#9, #32];
  Var
    pCL, pTail: PChar;
    InQuote: Boolean;
    ArgNo, N: LongInt;
  Begin
  pCL := GetCommandLine;
  pTail := Nil;
  If pCL^ <> #0 Then
    Begin
    InQuote := False;
    pTail := pCL;
    ArgNo := 0;
    For N := 0 To StrLen(pCL) Do
      Begin
      Case pCL[N] Of
        #0:
          Break;
        '"':
          Begin
          InQuote := Not InQuote;
          If InQuote Then
            Begin
            If ArgNo = 1 Then
              Break;
            End;
          Inc(pTail);
          End;
        #9,#32:
          Begin
          If (Not InQuote) And (Not (pCL[N - 1] In WHITESPACE)) Then
            Inc(ArgNo);
          Inc(pTail);
          End;
        Else
          Begin
          If ArgNo = 1 Then
            Break
          Else
            Inc(pTail);
          End;
      End; //Case
      End;
    End;
  GetCommandTail := pTail;
  End;

Begin
  pCommandTail := GetCommandTail;
  If StrLen(pCommandTail) > 0 Then
    {$IFNDEF GUI}
    WriteLn(pCommandTail);
    {$ELSE}
    MessageBox(0, pCommandTail, 'ShowArgs-GUI', 0);
    {$ENDIF}
End.
